#ifndef __MDFN_PSX_INPUT_GAMEPAD_H
#define __MDFN_PSX_INPUT_GAMEPAD_H

namespace MDFN_IEN_PSX
{

InputDevice *Device_Gamepad_Create(void);
extern IDIISG Device_Gamepad_IDII;
extern IDIISG Device_Dancepad_IDII;

}
#endif
